@@ -4,10 +4,11 @@ Additionally triggered by the escape key.
 """
 import logging
 
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..steps import Step
-from ..ui_framework import Interaction
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.steps import Step
+from ansible_navigator.ui_framework import Interaction
+
 from . import _actions as actions
 
 
@@ -37,10 +38,14 @@ class Action:
         this = app.steps.back_one()  # pop this
         step = app.steps.back_one()  # pop current
 
-        if app.steps:
-            if isinstance(step, Step) and isinstance(app.steps.current, Step):
-                if step.type == "menu" and app.steps.current.type == "menu":
-                    interaction.ui.menu_filter(None)
+        if (
+            app.steps
+            and isinstance(step, Step)
+            and isinstance(app.steps.current, Step)
+            and step.type == "menu"
+            and app.steps.current.type == "menu"
+        ):
+            interaction.ui.menu_filter(None)
             self._logger.debug(
                 "Stepping back in %s from %s to %s",
                 app.name,
