@@ -22,6 +22,7 @@ import shlex
 
 from collections.abc import Mapping
 from datetime import datetime
+from datetime import timezone
 from enum import IntEnum
 from typing import Any
 
@@ -355,7 +356,7 @@ class Action(ActionBase):
         self._calling_app.update()
 
         # Do this only every 2 seconds
-        if (datetime.now() - self._modification_times_last_updated).total_seconds() > 2:
+        if (datetime.now(timezone.utc) - self._modification_times_last_updated).total_seconds() > 2:
             rerun_lint = self._rerun_needed()
             if rerun_lint:
                 self._build_issues_menu()
@@ -506,7 +507,7 @@ class Action(ActionBase):
                 if unix_ts > previous_ts:
                     rerun_lint = True
 
-        self._modification_times_last_updated = datetime.now()
+        self._modification_times_last_updated = datetime.now(timezone.utc)
         if rerun_lint:
             self._logger.debug("Files modified")
         return rerun_lint
