@@ -1,9 +1,10 @@
 """``:quit`` command implementation."""
 import logging
 
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..ui_framework import Interaction
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.ui_framework import Interaction
+
 from . import _actions as actions
 
 
@@ -21,7 +22,6 @@ class Action:
         self._args = args
         self._logger = logging.getLogger(__name__)
 
-    # pylint: disable=unused-argument
     def run(self, interaction: Interaction, app: AppPublic) -> Interaction:
         """Handle a request to quit the application from the user interface.
 
