@@ -1,9 +1,10 @@
 """``:save`` command implementation."""
 import logging
 
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..ui_framework import Interaction
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.ui_framework import Interaction
+
 from . import _actions as actions
 
 
