@@ -6,9 +6,10 @@ or entry at the single line prompt. e.g ``:42``
 
 import logging
 
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..ui_framework import Interaction
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.ui_framework import Interaction
+
 from . import _actions as actions
 
 
