@@ -1,10 +1,11 @@
 """``:yaml`` command implementation."""
 import logging
 
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
 from ansible_navigator.content_defs import ContentFormat
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..ui_framework import Interaction
+from ansible_navigator.ui_framework import Interaction
+
 from . import _actions as actions
 
 
@@ -22,7 +23,6 @@ class Action:
         self._args = args
         self._logger = logging.getLogger(__name__)
 
-    # pylint: disable=unused-argument
     def run(self, interaction: Interaction, app: AppPublic) -> None:
         """Execute the ``:yaml`` request for mode interactive.
 
