@@ -8,14 +8,15 @@ import html
 
 from collections.abc import Mapping
 
-from ..action_base import ActionBase
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..content_defs import ContentFormat
-from ..ui_framework import Interaction
-from ..ui_framework import warning_notification
-from ..utils.functions import remove_dbl_un
-from ..utils.functions import templar
+from ansible_navigator.action_base import ActionBase
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.content_defs import ContentFormat
+from ansible_navigator.ui_framework import Interaction
+from ansible_navigator.ui_framework import warning_notification
+from ansible_navigator.utils.functions import remove_dbl_un
+from ansible_navigator.utils.functions import templar
+
 from . import _actions as actions
 
 
@@ -40,7 +41,6 @@ class Action(ActionBase):
         :returns: The pending :class:`~ansible_navigator.ui_framework.ui.Interaction` or
             :data:`None`
         """
-        # pylint: disable=too-many-branches
         self._logger.debug("template requested '%s'", interaction.action.value)
         self._prepare_to_run(app, interaction)
 
