@@ -76,11 +76,17 @@ def log_dependencies() -> list[LogMessage]:
     """
     pkgs = []
     found = []
-    for _python_name, pkg_names in importlib_metadata.packages_distributions().items():
+    messages: list[LogMessage] = []
+    for pkg_names in importlib_metadata.packages_distributions().values():
         for pkg_name in pkg_names:
             if pkg_name not in found:
                 found.append(pkg_name)
-                spec = find_spec(pkg_name)
+                try:
+                    spec = find_spec(pkg_name)
+                except ModuleNotFoundError:
+                    message = f"Package '{pkg_name}' is missing"
+                    messages.append(LogMessage(level=logging.DEBUG, message=message))
+                    continue
                 _location = spec.origin if spec else ""
                 _version = version(pkg_name)
                 pkgs.append(f"{pkg_name}=={_version} {_location}")
