@@ -15,6 +15,7 @@ from collections import Counter
 from collections import OrderedDict
 from collections.abc import Generator
 from datetime import datetime
+from datetime import timezone
 from json.decoder import JSONDecodeError
 from pathlib import Path
 from typing import TYPE_CHECKING
@@ -330,7 +331,7 @@ class CollectionCatalog:
             if collection_directory.exists():
                 self._one_path(collection_directory)
         self.add_pseudo_builtin()
-        for _collection_path, collection in self._collections.items():
+        for collection in self._collections.values():
             self._catalog_plugins(collection)
             self._catalog_roles(collection)
         self._find_shadows()
@@ -393,7 +394,7 @@ def worker(pending_queue: multiprocessing.Queue, completed_queue: multiprocessin
                     "returndocs": returndocs,
                     "metadata": metadata,
                 },
-                "timestamp": datetime.utcnow().isoformat(),
+                "timestamp": datetime.now(timezone.utc).isoformat(),
             }
             completed_queue.put(("plugin", (checksum, json.dumps(q_message, default=str))))
         except JSONDecodeError as exc:
@@ -411,7 +412,7 @@ def identify_missing(collections: dict, collection_cache: KeyValueStore) -> tupl
     handled = set()
     missing = []
     plugin_count = 0
-    for _collection_path, collection in collections.items():
+    for collection in collections.values():
         for checksum, details in collection["plugin_checksums"].items():
             plugin_count += 1
             if checksum not in handled:
@@ -575,7 +576,7 @@ def main() -> dict:
     cached_checksums = collection_cache.keys()
     stats["cache_length"] = len(collection_cache.keys())
 
-    for _collection_path, collection in collections.items():
+    for collection in collections.values():
         for no_doc in set(collection["plugin_checksums"].keys()) - set(cached_checksums):
             del collection["plugin_checksums"][no_doc]
 
@@ -589,7 +590,7 @@ def main() -> dict:
 
 
 if __name__ == "__main__":
-    start_time = datetime.now()
+    start_time = datetime.now(timezone.utc)
 
     collection_paths = retrieve_collections_paths()
     if "error" in collection_paths:
@@ -603,6 +604,6 @@ if __name__ == "__main__":
     os.environ["ANSIBLE_COLLECTIONS_PATHS"] = COLLECTION_SCAN_PATHS
 
     result = main()
-    result["stats"]["duration"] = (datetime.now() - start_time).total_seconds()
+    result["stats"]["duration"] = (datetime.now(timezone.utc) - start_time).total_seconds()
     result["collection_scan_paths"] = COLLECTION_SCAN_PATHS
     print(json.dumps(result, default=str))
