@@ -2,18 +2,20 @@
 from __future__ import annotations
 
 import json
-import multiprocessing
+import os
 import re
 import subprocess
 import sys
+import threading
 
 from queue import Queue
 from types import SimpleNamespace
 from typing import Any
 from typing import Callable
+from typing import Union
 
 
-PROCESSES = (multiprocessing.cpu_count() - 1) or 1
+JSONTypes = Union[bool, int, str, dict, list]
 
 
 class Command(SimpleNamespace):
@@ -47,7 +49,7 @@ def run_command(command: Command) -> None:
         command.errors = [str(exc.stderr)]
 
 
-def worker(pending_queue: multiprocessing.Queue, completed_queue: multiprocessing.Queue) -> None:
+def worker(pending_queue: Queue, completed_queue: Queue) -> None:
     """Run a command from pending, parse, and place in completed.
 
     :param pending_queue: A queue with plugins to process
@@ -76,28 +78,8 @@ class CommandRunner:
         self._completed_queue: Queue | None = None
         self._pending_queue: Queue | None = None
 
-    @staticmethod
-    def run_single_process(command_classes: Any):
-        """Run commands with a single process.
-
-        :param command_classes: All command classes to be run
-        :returns: The results from running all commands
-        """
-        all_commands = tuple(
-            command for command_class in command_classes for command in command_class.commands
-        )
-        results = []
-        for command in all_commands:
-            run_command(command)
-            try:
-                command.parse(command)
-            except Exception as exc:  # noqa: BLE001
-                command.errors = command.errors + [str(exc)]
-            results.append(command)
-        return results
-
-    def run_multi_process(self, command_classes):
-        """Run commands with multiple processes.
+    def run_multi_thread(self, command_classes):
+        """Run commands with multiple threads.
 
         Workers are started to read from pending queue.
         Exit when the number of results is equal to the number
@@ -107,9 +89,9 @@ class CommandRunner:
         :returns: The results from running all commands
         """
         if self._completed_queue is None:
-            self._completed_queue = multiprocessing.Manager().Queue()
+            self._completed_queue = Queue()
         if self._pending_queue is None:
-            self._pending_queue = multiprocessing.Manager().Queue()
+            self._pending_queue = Queue()
         results = {}
         all_commands = tuple(
             command for command_class in command_classes for command in command_class.commands
@@ -125,10 +107,10 @@ class CommandRunner:
 
         :param jobs: The jobs to be run
         """
-        worker_count = min(len(jobs), PROCESSES)
+        worker_count = len(jobs)
         processes = []
         for _proc in range(worker_count):
-            proc = multiprocessing.Process(
+            proc = threading.Thread(
                 target=worker,
                 args=(self._pending_queue, self._completed_queue),
             )
@@ -163,33 +145,51 @@ class CmdParser:
         :returns: The first partition, separator, and final partition
         """
         separator_match = re.search(separator, content)
-        if not separator_match:
-            return content, "", ""
-        matched_separator = separator_match.group(0)
-        parts = re.split(matched_separator, content, 1)
-        return parts[0], matched_separator, parts[1]
+        if not separator_match or content.startswith(" "):
+            return "", "", content
+        delim = separator_match.group(0)
+        key, content = re.split(delim, content, maxsplit=1)
+        return key, delim, content
 
-    def splitter(self, lines, delimiter):
+    def splitter(self, lines, line_split, section_delim=None):
         """Split lines given a delimiter.
 
         :param lines: The lines to split
-        :param delimiter: The delimiter to use for splitting
+        :param line_split: The delimiter use for splitting each line
+        :param section_delim: The separator between different packages
         :returns: All lines split on the delimiter
         """
         results = []
         result = {}
+        current_key = ""
         while lines:
-            line = lines.pop()
-            left, delim, right = self.re_partition(line, delimiter)
-            right = self._strip(right)
-            if not delim:
-                if result:
-                    results.append(result)
-                    result = {}
+            line = lines.pop(0)
+            key, delim, content = self.re_partition(line, line_split)
+            content = self._strip(content)
+            if section_delim and line == section_delim:
+                results.append(result)
+                result = {}
                 continue
-            key = left.lower().replace("_", "-").strip()
-            value = right
-            result[key] = value
+            if not delim and current_key:
+                result[current_key] += f" {content}"
+                continue
+            current_key = key.lower().replace("_", "-").strip()
+            # system_packages description field needs special handling
+            if current_key == "description":
+                description = []
+                while lines:
+                    line = lines.pop(0)
+                    if line == section_delim:
+                        break
+                    description.append(line)
+                if description:
+                    result[current_key] = " ".join(description)
+                else:
+                    result[current_key] = "No description available"
+                results.append(result)
+                return result
+            result[current_key] = content
+
         if result:
             results.append(result)
         return results
@@ -280,12 +280,18 @@ class PythonPackages(CmdParser):
 
         :returns: The defined command
         """
-        pre = Command(id_="pip_freeze", command="python3 -m pip freeze", parse=self.parse_freeze)
+        pre = Command(
+            id_="pip_freeze", command="/usr/bin/python3 -m pip freeze", parse=self.parse_freeze
+        )
         run_command(pre)
         pre.parse(pre)
-        pkgs = " ".join(pkg for pkg in pre.details[0])
+        pkgs = " ".join(pkg for pkg in pre.details[0]) if pre.details else ""
         return [
-            Command(id_="python_packages", command=f"python3 -m pip show {pkgs}", parse=self.parse),
+            Command(
+                id_="python_packages",
+                command=f"/usr/bin/python3 -m pip show {pkgs}",
+                parse=self.parse,
+            ),
         ]
 
     def parse(self, command):
@@ -293,7 +299,7 @@ class PythonPackages(CmdParser):
 
         :param command: The result of running the command
         """
-        parsed = self.splitter(command.stdout.splitlines(), ":")
+        parsed = self.splitter(command.stdout.splitlines(), line_split=":", section_delim="---")
         for pkg in parsed:
             for entry in ["required-by", "requires"]:
                 if pkg[entry]:
@@ -362,36 +368,21 @@ class SystemPackages(CmdParser):
 
         parsed = []
         for package in packages:
-            entry = {}
-            while package:
-                line = package.pop(0)
-                left, _delim, right = self.re_partition(line, ":")
-                key = left.lower().replace("_", "-").strip()
-
-                # Description is at the end of the package section
-                # read until package is empty
-                if key == "description":
-                    description = []
-                    while package:
-                        description.append(package.pop(0))
-                    # Normalize the data, in the case description is totally empty
-                    if description:
-                        entry[key] = "\n".join(description)
-                    else:
-                        entry[key] = "No description available"
-                    parsed.append(entry)
-                # other package details are 1 line each
-                else:
-                    value = self._strip(right)
-                    entry[key] = value
+            result = self.splitter(package, line_split=":")
+            parsed.append(result)
 
         command.details = parsed
 
 
-def main():
-    """Enter the image introspection process."""
-    response = {"errors": []}
+def main(serialize: bool = True) -> dict[str, JSONTypes] | None:
+    """Enter the image introspection process.
+
+    :param serialize: Whether to serialize the results
+    :returns: The collected data or none if serialize is False
+    """
+    response: dict = {"errors": []}
     response["python_version"] = {"details": {"version": " ".join(sys.version.splitlines())}}
+    response["environment_variables"] = {"details": dict(os.environ)}
     try:
         command_runner = CommandRunner()
         commands = [
@@ -402,7 +393,7 @@ def main():
             PythonPackages(),
             SystemPackages(),
         ]
-        results = command_runner.run_multi_process(commands)
+        results = command_runner.run_multi_thread(commands)
         for result in results:
             result_as_dict = vars(result)
             result_as_dict.pop("parse")
@@ -413,7 +404,10 @@ def main():
             response[result_as_dict["__id_"]] = result_as_dict
     except Exception as exc:  # noqa: BLE001
         response["errors"].append(str(exc))
-    print(json.dumps(response))
+    if serialize:
+        print(json.dumps(response))
+        return None
+    return response
 
 
 if __name__ == "__main__":
