@@ -19,3 +19,9 @@ if sys.version_info < (3, 10):
     import importlib_metadata
 else:
     import importlib.metadata as importlib_metadata
+
+
+if sys.version_info < (3, 12):
+    from importlib.abc import Traversable
+else:
+    from importlib.resources.abc import Traversable
